Added the timing of the graph building and tracking in seconds.
[mtp.git] / mtp.cc
diff --git a/mtp.cc b/mtp.cc
index b80c472..36f09f1 100644 (file)
--- a/mtp.cc
+++ b/mtp.cc
@@ -1,31 +1,36 @@
 
-///////////////////////////////////////////////////////////////////////////
-// This program is free software: you can redistribute it and/or modify  //
-// it under the terms of the version 3 of the GNU General Public License //
-// as published by the Free Software Foundation.                         //
-//                                                                       //
-// This program is distributed in the hope that it will be useful, but   //
-// WITHOUT ANY WARRANTY; without even the implied warranty of            //
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      //
-// General Public License for more details.                              //
-//                                                                       //
-// You should have received a copy of the GNU General Public License     //
-// along with this program. If not, see <http://www.gnu.org/licenses/>.  //
-//                                                                       //
-// Written by and Copyright (C) Francois Fleuret                         //
-// Contact <francois.fleuret@idiap.ch> for comments & bug reports        //
-///////////////////////////////////////////////////////////////////////////
-
-// Multi-Tracked Path
+/*
+ *  mtp is the ``Multi Tracked Paths'', an implementation of the
+ *  k-shortest paths algorithm for multi-target tracking.
+ *
+ *  Copyright (c) 2012 Idiap Research Institute, http://www.idiap.ch/
+ *  Written by Francois Fleuret <francois.fleuret@idiap.ch>
+ *
+ *  This file is part of mtp.
+ *
+ *  mtp is free software: you can redistribute it and/or modify it
+ *  under the terms of the GNU General Public License version 3 as
+ *  published by the Free Software Foundation.
+ *
+ *  mtp is distributed in the hope that it will be useful, but WITHOUT
+ *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+ *  License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with selector.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
 
 #include <iostream>
 #include <fstream>
 
 using namespace std;
 
-#include "tracker.h"
+#include "mtp_tracker.h"
 
 int main(int argc, char **argv) {
+  time_t start_time, end_time;
 
   if(argc < 2) {
     cerr << argv[0] << " <tracker file>" << endl;
@@ -36,13 +41,22 @@ int main(int argc, char **argv) {
 
   if(in_tracker->good()) {
 
-    Tracker *tracker = new Tracker();
+    MTPTracker *tracker = new MTPTracker();
 
+    cout << "Reading " << argv[1] << "." << endl;
     tracker->read(in_tracker);
-    cout << "Read " << argv[1] << endl;
 
+    cout << "Building the graph ... "; cout.flush();
+    start_time = time(0);
     tracker->build_graph();
+    end_time = time(0);
+    cout << "done (" << end_time - start_time << "s)." << endl;
+
+    cout << "Tracking ... "; cout.flush();
+    start_time = time(0);
     tracker->track();
+    end_time = time(0);
+    cout << "done (" << end_time - start_time << "s)." << endl;
 
     ofstream out_traj("result.trj");
     tracker->write_trajectories(&out_traj);